Description Usage Arguments Details See Also
Where one prescription (for the same drug and patient) starts only a short time after the previous finishes, this function can close the gap, as if the prescription was continuous over the entire period.
1 | decision_10(data, decision = "a")
|
data |
a data frame |
decision |
one of the following strings:
|
The underlying function is called close_small_gaps
Other decision functions:
decision_1(),
decision_2(),
decision_3(),
decision_4(),
decision_5(),
decision_6(),
decision_7(),
decision_8(),
decision_9(),
drug_prep()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.