Learn R Programming

drugprepr (version 0.0.4)

decision_6: Decision 6: choose method of calculating prescription duration

Description

This is just shorthand for defining a column equal to one of the specified formulae. If the column(s) corresponding to decision are missing, an error will be thrown. If you have already calculated or obtained the column duration from elsewhere, this step is not necessary.

Usage

decision_6(data, decision = "c")

Arguments

data

a data frame

decision

one of the following strings:

"a"

numdays

"b"

dose_duration

"c"

qty / ndd

See Also

Other decision functions: decision_10(), decision_1(), decision_2(), decision_3(), decision_4(), decision_5(), decision_7(), decision_8(), decision_9(), drug_prep()