A light wrapper around impute_duration, followed by removing
duplicate rows with the same combination of prodcode, patid
and start_date.
decision_8(data, decision = "a")a data frame
one of the following strings
do nothing
replace with a prescription of duration equal to the mean
choose the shortest prescription
choose longest prescription
replace with a prescription of duration equal to the sum
Other decision functions:
decision_10(),
decision_1(),
decision_2(),
decision_3(),
decision_4(),
decision_5(),
decision_6(),
decision_7(),
decision_9(),
drug_prep()