In situations where one prescription starts before another (for the same patient and drug) finishes, this function will either implicitly sum the doses (i.e. do nothing) or it will divide the intervals into non-overlapping subsets, shifting these sub-intervals forward in time until there is no overlap.
decision_9(data, decision = "a")a data frame
one of the following strings:
allow overlapping prescriptions (implicitly sum doses)
move later prescription to next available time that this product is not prescribed
The underlying algorithm for shifting overlapping intervals is implemented
by the internal function shift_interval.
Other decision functions:
decision_10(),
decision_1(),
decision_2(),
decision_3(),
decision_4(),
decision_5(),
decision_6(),
decision_7(),
decision_8(),
drug_prep()