Learn R Programming

drugprepr (version 0.0.4)

impute_qty: Find implausible entries Replace implausible or missing prescription quantities

Description

Find implausible entries Replace implausible or missing prescription quantities

Usage

impute_qty(data, method, where = is.na, group = "population", ...)

Arguments

data

A data frame containing columns prodcode, pracid, patid

method

Method for imputing the values. See details.

where

Logical vector, or function applied to variable returning such a vector, indicating which elements to impute. Defaults to is.na

group

Level of structure for imputation. Defaults to whole study population.

...

Extra arguments, currently ignored

Value

A data frame of the same structure as data, with values imputed

Examples

Run this code
# NOT RUN {
impute_qty(example_therapy, 'mean')

# }

Run the code above in your browser using DataLab