Where one prescription (for the same drug and patient) starts only a short time after the previous finishes, this function can close the gap, as if the prescription was continuous over the entire period.
decision_10(data, decision = "a")a data frame
one of the following strings:
do nothing
change stop date of first prescription to start date of next if gap is \(\leq 15\) days
change stop date of first prescription to start date of next if gap is \(\leq 30\) days
change stop date of first prescription to start date of next if gap is \(\leq 60\) days
The underlying function is called close_small_gaps
Other decision functions:
decision_1(),
decision_2(),
decision_3(),
decision_4(),
decision_5(),
decision_6(),
decision_7(),
decision_8(),
decision_9(),
drug_prep()