This is just shorthand for defining a column equal to one of the specified
formulae. If the column(s) corresponding to decision are missing, an
error will be thrown.
If you have already calculated or obtained the column duration from
elsewhere, this step is not necessary.
decision_6(data, decision = "c")a data frame
one of the following strings:
numdays
dose_duration
qty / ndd
Other decision functions:
decision_10(),
decision_1(),
decision_2(),
decision_3(),
decision_4(),
decision_5(),
decision_7(),
decision_8(),
decision_9(),
drug_prep()