powered by
Replace implausible or missing numerical daily doses (NDD)
impute_ndd(data, method, where = is.na, group = "population", ...)
A data frame containing columns prodcode, pracid, patid
prodcode
pracid
patid
Method for imputing the values. See details.
Logical vector, or function applied to variable returning such a vector, indicating which elements to impute. Defaults to is.na
variable
is.na
Level of structure for imputation. Defaults to whole study population.
Extra arguments, currently ignored
A data frame of the same structure as data, with values imputed
data
# NOT RUN { impute_ndd(example_therapy, 'mean') # }
Run the code above in your browser using DataLab